#
# spec file for package waylyrics
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           waylyrics
Version:        0.2.2
Release:        1.1
Summary:        The furry way to show desktop lyrics
License:        MIT
URL:            https://github.com/waylyrics/waylyrics
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo >= 1.73.0
BuildRequires:  cargo-packaging
BuildRequires:  dbus-1-devel
BuildRequires:  gtk4-devel
BuildRequires:  libgraphene-devel
BuildRequires:  mimalloc-devel
BuildRequires:  openssl-devel

# Override "-C debuginfo=2" from cargo-packaging, to solve rustc SIGSEGV exception:
#   error: rustc interrupted by SIGSEGV, printing backtrace
#   /usr/lib/librustc_driver-16d66626a1fefc07.so(+0x7aafa6)[0x7fbd6ffaafa6]
# Tested with rustc 1.75.0 (82e1608df 2023-12-21) by xtexChooser
%global build_rustflags %build_rustflags -C debuginfo=0

%description
The furry way to show desktop lyrics, and simple universal desktop lyrics made with GTK4 and love.

%prep
%autosetup -a1 -p0

%build
export WAYLYRICS_THEME_PRESETS_DIR=%{_datadir}/waylyrics/themes
%{cargo_build} --locked

%install
export WAYLYRICS_THEME_PRESETS_DIR=%{_datadir}/waylyrics/themes
# locked is required as waylyrics includes some git dependencies
%{cargo_install} --locked

install -d %{buildroot}%{_datadir}/waylyrics
cp -r themes %{buildroot}%{_datadir}/waylyrics/

install -Dm644 "io.poly000.waylyrics.desktop" -t %{buildroot}%{_datadir}/applications/
install -Dm644 "io.poly000.waylyrics.gschema.xml" -t %{buildroot}%{_datadir}/glib-2.0/schemas/

%check
export WAYLYRICS_THEME_PRESETS_DIR=%{_datadir}/waylyrics/themes
%{cargo_test} --locked --no-default-features --features mimalloc

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/waylyrics/
%{_datadir}/applications/io.poly000.waylyrics.desktop
%{_datadir}/glib-2.0/schemas/io.poly000.waylyrics.gschema.xml

%changelog
* Sat Feb 10 2024 xtexchooser@duck.com
- Update to version 0.2.2:
  * chore: release `v0.2.2`
  * build: Add ability to disable tests require network
  * ci: test qqmusic provider initializing
  * fix: QQMusic::init should panic on `Err()` rather than `Ok()`
* Fri Feb  9 2024 xtexchooser@duck.com
- Update to version 0.2.1:
  * chore: release 0.2.1
  * build: improve test build time
  * test: move out doctest for `get_lrc_path`
  * test: move unit tests to inside `src/`
  * refactor: rename `get_lyric` to `parse_lyric` [ci skip]
  * refactor: setup `QQMusic` with `init()` call
  * doc(install): download pre-built executables [ci skip]
  * doc(install): explain build environment variable
  * ci: run real test in CI
  * test: test LRC parsing
  * doc: define `lrc_iter` behaviour
  * refactor: impl into_owned for LyricLine
  * test: test netease lyric get & parse
  * refactor: remove `CONFIG_HOME`
  * chore: remove unused import
  * breaking(ui): drop `SIGUSR` control support
  * refactor: make `init_dirs` a public method so we could write tests
  * chore: release 0.2.0
  * style: define `glib-macros` under `gtk`
  * doc(readme): remove `lx-music` because it's dead [ci skip]
  * chore(doc): add `musicfox`, a TUI based music player [ci skip]
  * fix: hint support for musicfox
  * chore(doc): update doc for youtube-music [ci skip]
  * chore: drop support for ncm-gtk legacy name
  * feat: add support for musicfox
  * chore(doc): update translation [ci skip]
  * chore(doc): update alternatives [ci skip]
* Wed Feb  7 2024 xtexchooser@duck.com
- Update to version 0~git486:
  * fix: override user theme
  * fix: ignore invalid LRC lines
  * code quality: remove unused last_played_lyric_index
  * chore: clean up lyric scroll
  * chore: replace `with_borrow_mut` with `set` [ci skip]
  * chore: openSUSE official package thanks to @xtexChooser
  * fix: desktop file does not need a launch action [ci skip]
  * chore(doc): mention desktop file for global shortcut
  * refactor: move out update_lyric
  * build(rpm): fix install
  * chore: intro openssl/vendored to vendored feature [ci skip]
* Fri Feb  2 2024 xtexChooser <xtexchooser@duck.com>
- Remove tar.zst packaged sources, keep obscpio only
- Change versioning to follow package versioning guidelines
* Fri Feb  2 2024 xtexChooser <xtexchooser@duck.com>
- Remove rpm "Group"
* Thu Feb  1 2024 xtexChooser <xtexchooser@duck.com>
- Update vendored crates
* Thu Feb  1 2024 xtexChooser <xtexchooser@duck.com>
- Init waylyrics from upstream commit aed689ef481dd2ddf22cefc0d175fabee481cdb8
